@@ -4,15 +4,8 @@
 use std::fmt;
 use std::fmt::Debug;
 use position::span::Span;
-extern crate ansi_term;
-use self::ansi_term::Color::*;
-use self::ansi_term::Color;
-
-/// Color code for errors used throughout entire error reporting system.
-#[deprecated(since = "0.4.1")]
-pub const ERROR_COLORS: [Color; 4] = [
-    Red, Cyan, Green, Cyan,
-];
+extern crate colored;
+use self::colored::{ColoredString, Colorize};
 
 /// Enum for error levels.
 #[derive(Debug, Copy, Clone)]
@@ -25,33 +18,23 @@ pub enum ErrorLevel {
 
 impl fmt::Display for ErrorLevel {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{}", match self {
-            &ErrorLevel::Warning => Yellow,
-            &ErrorLevel::Error   => Red,
-        }.paint(format!("{:?}", self)))
+        let s: &str = &format!("{:?}", self);
+        let c: ColoredString;
+        match *self {
+            ErrorLevel::Warning => {c = s.yellow()},
+            ErrorLevel::Error   => {c = s.red()},
+        }
+        write!(f, "{}", c)
     }
 }
 
-/// Color for names which are printed by the compiler.
-pub const NAME_COLOR: Color = Green;
-
-/// Color for modules when printed by the compiler.
-pub const MODULE_COLOR: Color = Cyan;
-
-/// Color for dividing bars used when displaying errors.
-pub const BAR_COLOR: Color = Cyan;
-
-/// Color for info line displayed.
-pub const INFO_COLOR: Color = Blue;
-
-/// Color for underlining arrows for error spans.
-pub const ARROW_COLOR: Color = Red;
-
-/// Color for source code that is displayed in error reporting.
-pub const CONTENT_COLOR: Color = Green;
-
 /// Trait for Errors. Any error used throughout the wright compiler/interpreter must implement
 /// this trait for consistency.
+///
+/// #### Lifetime Clarification:
+/// 'source lifetime represents the time during which the source code being interpreted is alive.
+/// 'error  lifetime represents the time during which the error is alive.
+/// 'source is required to be longer than 'error
 pub trait Error<'source: 'error, 'error> : Debug + Sized {
     /// Return the name of the error.
     fn get_name(&'error self)   -> &'error str;
@@ -62,17 +45,17 @@ pub trait Error<'source: 'error, 'error> : Debug + Sized {
     /// Returns the error level.
     fn get_level(&self) -> ErrorLevel;
 
-    /// Returns a slice of the content spans of the offending content.
+    /// Returns a vector of the content spans of the offending content.
     ///
     /// If there are no spans (the vector is empty) then line numbers will not
-    /// be used in error reporting. (The entire source will be printed.)
+    /// be used in error reporting.
     ///
     /// Spans must be single line only. (The error is invalid otherwise.)
-    fn get_spans(&'error self) -> &'error [Span];
+    fn get_spans(&'error self) -> Vec<Span>;
 
     /// Return information about the error.
     ///
-    /// The first entry is displayed as the error information at the top of the error
+    /// The first item is displayed as the error information at the top of the error
     /// and the following ones are displayed next to the the underlining string for each span.
     ///
     /// Any additional information (past the appropriate number for the given set of spans)
@@ -80,7 +63,7 @@ pub trait Error<'source: 'error, 'error> : Debug + Sized {
     ///
     /// If the vector is empty or too short then each informative will default to an empty string
     /// except for the first one, which defaults to "An error occurred."
-    fn get_info(&'error self) -> &'error [&'error str];
+    fn get_info(&'error self) -> Vec<&'error str>;
 
     /// Return a reference to the source code of the module (file) containing the error.
     /// Or the source of the error if it was not in code.
@@ -111,7 +94,9 @@ pub trait Error<'source: 'error, 'error> : Debug + Sized {
     /// (ErrorToDisplay implements fmt::Display)
     ///
     /// # Panics
-    /// Panics if validate() returns an Err().
+    /// Panics if [`validate()`] returns an Err(()).
+    ///
+    /// [`validate()`]: ./trait.Error.html#method.validate
     fn get_displayable(&'error self) ->  ErrorToDisplay<'source, 'error> {
         self.validate().unwrap();
         let result = ErrorToDisplay {
@@ -129,7 +114,9 @@ pub trait Error<'source: 'error, 'error> : Debug + Sized {
     /// Displays a given error via the get_displayable method.
     ///
     /// # Panics
-    /// Panics if validate() returns and Err().
+    /// Panics if [`validate()`] returns and Err().
+    ///
+    /// [`validate()`]: ./trait.Error.html#method.validate
     fn display(&'error self) {
         self.get_displayable().display();
     }
@@ -145,7 +132,7 @@ pub struct ErrorToDisplay<'src, 'err> {
     line_info:      String,
     error_info:     Vec<String>,
     source_lines:   &'src [&'src str],
-    spans:          &'err [Span],
+    spans:          Vec<Span>,
 }
 
 impl<'src, 'err> ErrorToDisplay<'src, 'err> {
@@ -155,7 +142,7 @@ impl<'src, 'err> ErrorToDisplay<'src, 'err> {
     }
     // not pub because it doesn't need to be and it is pretty specific.
     /// Takes vec of spans and uses it to set line info.
-    fn get_line_info(span_vec: &'err [Span]) -> String {
+    fn get_line_info(span_vec: Vec<Span>) -> String {
         if span_vec.is_empty() { "".to_string() }
         else {
             format!("on line {}.", span_vec
@@ -171,21 +158,22 @@ impl<'source, 'spans> fmt::Display for ErrorToDisplay<'source, 'spans> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let width = 5;
         let five = " ".repeat(width);
-        let bar = BAR_COLOR.paint("|");
+        let bar = "|".cyan();
         let info = self.clone().error_info;
         let mut info_iter = info.iter();
         let no_span = self.spans.is_empty();
         let mut span_iter = self.spans.iter();
         writeln!(f, "{level}: {n} in {m} {l_info}\n{f}{info}\n{f} {b}",
             level = format!("{}", self.level),
-            n = NAME_COLOR.paint(self.name.clone()),
-            m = MODULE_COLOR.paint(self.module.clone()),
+            n = self.name.clone().green(),
+            m = self.module.clone().cyan(),
             l_info = self.line_info,
             f = five,
             b = bar,
-            info = INFO_COLOR.paint(info_iter.next()
+            info = info_iter.next()
                 .unwrap_or(&"An Error Occurred.".to_string())
-                .as_str()),
+                .as_str()
+                .blue(),
         )?;
         while let Some(span) = span_iter.next() {
             let current_line: &str = self.source_lines
@@ -204,16 +192,20 @@ impl<'source, 'spans> fmt::Display for ErrorToDisplay<'source, 'spans> {
             writeln!(f, "{prev:>w$} {b} {p_line}\n{cur:>w$} {b} {c_line}\n{f} {b} {a_line} {info}",
                 prev = span.get_start().get_line()-1,
                 cur = span.get_start().get_line(),
-                p_line = CONTENT_COLOR.paint(
-                    self.source_lines.get(span.get_start().get_line()-2).unwrap().trim_right()),
-                c_line = CONTENT_COLOR.paint(current_line),
+                p_line = self.source_lines
+                    .get(span.get_start().get_line()-2)
+                    .unwrap()
+                    .trim_right()
+                    .green(),
+                c_line = current_line.green(),
                 w = width,
                 b = bar,
                 f = five,
-                a_line = ARROW_COLOR.paint(arrow_line),
-                info = INFO_COLOR.paint(info_iter.next()
+                a_line = arrow_line.red(),
+                info = info_iter.next()
                     .unwrap_or(&"".to_string())
-                    .as_str()),
+                    .as_str()
+                    .blue(),
             )?;
         }
         if no_span {
@@ -221,7 +213,7 @@ impl<'source, 'spans> fmt::Display for ErrorToDisplay<'source, 'spans> {
                 writeln!(f, "{f} {b} {l}",
                     f= five,
                     b = bar,
-                    l = CONTENT_COLOR.paint(*line),
+                    l = line.green(),
                 )?;
             }
         }
